<?php

/*
* Get Top Release
*/
function getTopRelease($time = 'all', $start = 0, $topics_per_page = 30)
{
	if(!intval($topics_per_page)) return;
	switch ($time) {
    case 'all':
			$start_time = 0;
			$end_time = TIMENOW;
			$order = 'tr.complete_count';
		break;
    case 'week':
			$start_time = strtotime('Monday last week');
			$end_time = TIMENOW;
			$order = 'tr.complete_count';
		break;
    case 'month':
			$start_time = strtotime('1 '.date('M').' '.date('Y'));
			$end_time = TIMENOW;
			$order = 'tr.complete_count';
		break;
    case '30days':
			$start_time = TIMENOW - (86400*30);
			$end_time = TIMENOW;
			$order = 'tr.complete_count';
		break;
    case 'replies':
			$start_time = TIMENOW - (86400*30);
			$end_time = TIMENOW;
			$order = 't.topic_replies';
		break;
    default:
			$start_time = 0;
			$end_time = TIMENOW;
			$order = 'tr.complete_count';
	}
	$sql = "SELECT tr.topic_id, tr.forum_id,
								 tr.attach_id, tr.size,
								 tr.reg_time, tr.poster_id,
								 tr.complete_count, tr.tor_status,
								 f.forum_name, f.forum_id,
								 t.topic_title, t.topic_id, t.topic_replies,
								 u.user_id, u.username
					FROM ".BB_BT_TORRENTS." AS tr,
							 ".BB_FORUMS."     AS f,
							 ".BB_TOPICS."     AS t,
							 ".BB_USERS."      AS u
					WHERE tr.reg_time > $start_time
					  AND tr.reg_time < $end_time
					  AND tr.poster_id NOT IN(".GUEST_UID.",".BOT_UID.")
					  AND f.forum_id = tr.forum_id
					  AND t.topic_id = tr.topic_id
					  AND u.user_id  = tr.poster_id
					ORDER BY $order DESC
					LIMIT $start, $topics_per_page";
	$cache_key = 'release_'.$time;
	CACHE('bb_cache')->rm($cache_key);
	if (!$data = CACHE('bb_cache')->get($cache_key))
	{
		$data = DB()->fetch_rowset($sql);
		CACHE('bb_cache')->set($cache_key, $data, 86400);
	}
	return $data;
}

/*
* Get Top Users
*/
function getTopUsers($mode = 'upload', $start = 0, $users_per_page = 30, $name = '')
{
	if(!intval($users_per_page)) return;
	$name_by = '';
	if($name)
	{
	  $name = DB()->escape($name);
		$name_by = "AND u.username LIKE '$name%'";
	}
	switch ($mode) {
    case 'upload':
			$order = 'ut.u_up_total';
		break;
    case 'download':
			$order = 'ut.u_down_total';
		break;
    case 'bonus':
			$order = 'ut.u_up_bonus';
		break;
    case 'release':
			$order = 'ut.u_up_release';
		break;
    case 'seedbonus':
			$order = 'u.user_points';
		break;
    case 'ratio':
			$order = '((ut.u_up_total + ut.u_up_release + ut.u_up_bonus) / ut.u_down_total)';
		break;
    default:
			$order = 'ut.u_up_total';
	}
	$sql = "SELECT ut.u_up_total, ut.u_down_total,
								 ut.u_up_release, ut.u_up_bonus, ut.user_id,
								 u.username, u.user_level, u.user_points
 					FROM ".BB_BT_USERS."   AS ut,
							 ".BB_USERS."      AS u
					WHERE ut.user_id NOT IN(".GUEST_UID.",".BOT_UID.")
					AND		ut.u_down_total > ".MIN_DL_FOR_RATIO."
					AND		u.user_id = ut.user_id
					AND   u.user_active > 0
					$name_by
					ORDER BY $order DESC
					LIMIT $start, $users_per_page";
	$cache_key = 'users_'. md5($sql);
	$dt = array();
	CACHE('bb_cache')->rm($cache_key);
	if (!$data = CACHE('bb_cache')->get($cache_key))
	{
		$data = DB()->fetch_rowset($sql);
		CACHE('bb_cache')->set($cache_key, $data, 86400);
	}
	$i = 0;
	foreach($data as $row)
	{
	  $dt[$i] = $row;
		$dt[$i]['ratio'] = get_bt_ratio($row);
		$i++;
	}
	return $dt;
}
